@@ -79,8 +79,8 @@ def start_model_server(handler_service=DEFAULT_HANDLER_SERVICE):
     if os.path.exists(REQUIREMENTS_PATH):
         _install_requirements()
 
-    mxnet_model_server_cmd = [
-        "mxnet-model-server",
+    multi_model_server_cmd = [
+        "multi-model-server",
         "--start",
         "--model-store",
         MODEL_STORE,
@@ -90,12 +90,11 @@ def start_model_server(handler_service=DEFAULT_HANDLER_SERVICE):
         DEFAULT_MMS_LOG_FILE,
     ]
 
-    logger.info(mxnet_model_server_cmd)
-    subprocess.Popen(mxnet_model_server_cmd)
-
+    logger.info(multi_model_server_cmd)
+    subprocess.Popen(multi_model_server_cmd)
     mms_process = _retrieve_mms_server_process()
-
     _add_sigterm_handler(mms_process)
+    _add_sigchild_handler()
 
     mms_process.wait()
 
@@ -205,3 +204,17 @@ def _retrieve_mms_server_process():
         raise Exception("multiple mms model servers are not supported")
 
     return mms_server_processes[0]
+
+
+def _reap_children(signo, frame):  # pylint: disable=unused-argument
+    """Cleans up all defunct child processes."""
+    pid = 1
+    try:
+        while pid > 0:
+            pid, status = os.waitpid(-1, os.WNOHANG)  # pylint: disable=unused-variable
+    except OSError:
+        logger.error("Failed to reap children process")
+
+
+def _add_sigchild_handler():
+    signal.signal(signal.SIGCHLD, _reap_children)
